@@ -48,8 +48,8 @@ use strict;
 
 use CGI::FormBuilder::Util;
 
-our $REVISION = do { (my $r='$Revision: 53 $') =~ s/\D+//g; $r };
-our $VERSION  = $CGI::FormBuilder::Util::VERSION;
+our $REVISION = do { (my $r='$Revision: 64 $') =~ s/\D+//g; $r };
+our $VERSION = '3.0401';
 our $AUTOLOAD;
 
 # what to generate for tag
@@ -103,25 +103,6 @@ use overload '""'   => sub { $_[0]->name },
              'bool' => sub { $_[0]->name },
              'eq'   => sub { $_[0]->name eq $_[1] };
 
-=for slower
-
-sub BEGIN {
-    eval "use Class::Accessor::Fast";
-    eval "use base 'Class::Accessor::Fast'";
-    unless ($@) {
-        # use these instead of AUTOLOAD
-        debug 1, "found Class::Accessor::Fast for speedup";
-        __PACKAGE__->mk_accessors(qw/
-            label jsclick onclick onchange
-            sticky required invalid missing
-            nameopts sortopts cleanopts optgroups order 
-            linebreaks selectname selectnum columns
-        /);
-    }
-}
-
-=cut
-
 sub new {
     puke "Not enough arguments for Field->new()" unless @_ > 1;
     my $self = shift;
@@ -1028,7 +1009,7 @@ L<CGI::FormBuilder>
 
 =head1 REVISION
 
-$Id: Field.pm 53 2006-08-25 20:41:38Z nwiger $
+$Id: Field.pm 64 2006-09-07 18:08:27Z nwiger $
 
 =head1 AUTHOR
 
